#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['tj_text', 'tj_text.typograph']

package_data = \
{'': ['*']}

extras_require = \
{'dev': ['ipython'], 'test': ['black', 'isort', 'flake8', 'pytest >=6.0.0']}

setup(name='tj-text',
      version='0.5.0',
      description='Tj text utils',
      author=None,
      author_email='Tj <tinkoffjournal@tjournal.tech>',
      url=None,
      packages=packages,
      package_data=package_data,
      extras_require=extras_require,
      python_requires='>=3.6',
     )
